@@ -6,6 +6,7 @@
 
 #include <cstring>
 
+#include "src/base/bits.h"
 #include "src/execution/isolate.h"
 #include "src/handles/global-handles.h"
 #include "src/logging/counters.h"
@@ -16,6 +17,7 @@
 #include "src/wasm/wasm-constants.h"
 #include "src/wasm/wasm-engine.h"
 #include "src/wasm/wasm-limits.h"
+#include "src/wasm/wasm-module.h"
 #include "src/wasm/wasm-objects-inl.h"
 #endif  // V8_ENABLE_WEBASSEMBLY
 
@@ -33,7 +35,8 @@ namespace {
 constexpr uint64_t kNegativeGuardSize = uint64_t{2} * GB;
 
 #if V8_TARGET_ARCH_64_BIT
-constexpr uint64_t kFullGuardSize = uint64_t{10} * GB;
+constexpr uint64_t kFullGuardSize32 = uint64_t{10} * GB;
+constexpr uint64_t kFullGuardSize64 = uint64_t{32} * GB;
 #endif
 
 #endif  // V8_ENABLE_WEBASSEMBLY
@@ -55,21 +58,32 @@ enum class AllocationStatus {
 };
 
 base::AddressRegion GetReservedRegion(bool has_guard_regions,
-                                      void* buffer_start,
+                                      bool is_wasm_memory64, void* buffer_start,
                                       size_t byte_capacity) {
 #if V8_TARGET_ARCH_64_BIT && V8_ENABLE_WEBASSEMBLY
   if (has_guard_regions) {
-    // Guard regions always look like this:
-    // |xxx(2GiB)xxx|.......(4GiB)..xxxxx|xxxxxx(4GiB)xxxxxx|
-    //              ^ buffer_start
-    //                              ^ byte_length
-    // ^ negative guard region           ^ positive guard region
-
     Address start = reinterpret_cast<Address>(buffer_start);
     DCHECK_EQ(8, sizeof(size_t));  // only use on 64-bit
     DCHECK_EQ(0, start % AllocatePageSize());
-    return base::AddressRegion(start - kNegativeGuardSize,
-                               static_cast<size_t>(kFullGuardSize));
+    if (is_wasm_memory64) {
+      DCHECK(v8_flags.wasm_memory64_trap_handling);
+      static_assert(kFullGuardSize64 ==
+                    2 * wasm::kV8MaxWasmMemory64Pages * wasm::kWasmPageSize);
+      DCHECK_LE(byte_capacity,
+                wasm::kV8MaxWasmMemory64Pages * wasm::kWasmPageSize);
+      return base::AddressRegion(
+          start,
+          1ULL << wasm::WasmMemory::GetMemory64GuardsShift(byte_capacity));
+    } else {
+      // Guard regions always look like this:
+      // |xxx(2GiB)xxx|.......(4GiB)..xxxxx|xxxxxx(4GiB)xxxxxx|
+      //              ^ buffer_start
+      //                              ^ byte_length
+      // ^ negative guard region           ^ positive guard region
+
+      return base::AddressRegion(start - kNegativeGuardSize,
+                                 static_cast<size_t>(kFullGuardSize32));
+    }
   }
 #endif
 
@@ -78,12 +92,22 @@ base::AddressRegion GetReservedRegion(bool has_guard_regions,
                              byte_capacity);
 }
 
-size_t GetReservationSize(bool has_guard_regions, size_t byte_capacity) {
+size_t GetReservationSize(bool has_guard_regions, size_t byte_capacity,
+                          bool is_wasm_memory64) {
 #if V8_TARGET_ARCH_64_BIT && V8_ENABLE_WEBASSEMBLY
   if (has_guard_regions) {
-    static_assert(kFullGuardSize > size_t{4} * GB);
-    DCHECK_LE(byte_capacity, size_t{4} * GB);
-    return kFullGuardSize;
+    if (is_wasm_memory64) {
+      DCHECK(v8_flags.wasm_memory64_trap_handling);
+      static_assert(kFullGuardSize64 ==
+                    2 * wasm::kV8MaxWasmMemory64Pages * wasm::kWasmPageSize);
+      DCHECK_LE(byte_capacity,
+                wasm::kV8MaxWasmMemory64Pages * wasm::kWasmPageSize);
+      return 1ULL << wasm::WasmMemory::GetMemory64GuardsShift(byte_capacity);
+    } else {
+      static_assert(kFullGuardSize32 >= size_t{4} * GB);
+      DCHECK_LE(byte_capacity, size_t{4} * GB);
+      return kFullGuardSize32;
+    }
   }
 #else
   DCHECK(!has_guard_regions);
@@ -97,28 +121,6 @@ void RecordStatus(Isolate* isolate, AllocationStatus status) {
       static_cast<int>(status));
 }
 
-inline void DebugCheckZero(void* start, size_t byte_length) {
-#ifdef DEBUG
-#ifdef V8_IS_TSAN
-  // TSan in debug mode is particularly slow. Skip this check for buffers >64MB.
-  if (byte_length > 64 * MB) return;
-#endif  // TSan debug build
-  // Double check memory is zero-initialized. Despite being DEBUG-only,
-  // this function is somewhat optimized for the benefit of test suite
-  // execution times (some tests allocate several gigabytes).
-  const uint8_t* bytes = reinterpret_cast<const uint8_t*>(start);
-  const size_t kBaseCase = 32;
-  for (size_t i = 0; i < kBaseCase && i < byte_length; i++) {
-    DCHECK_EQ(0, bytes[i]);
-  }
-  // Having checked the first kBaseCase bytes to be zero, we can now use
-  // {memcmp} to compare the range against itself shifted by that amount,
-  // thereby inductively checking the remaining bytes.
-  if (byte_length > kBaseCase) {
-    DCHECK_EQ(0, memcmp(bytes, bytes + kBaseCase, byte_length - kBaseCase));
-  }
-#endif
-}
 }  // namespace
 
 // The backing store for a Wasm shared memory remembers all the isolates
@@ -130,7 +132,7 @@ struct SharedWasmMemoryData {
 BackingStore::BackingStore(void* buffer_start, size_t byte_length,
                            size_t max_byte_length, size_t byte_capacity,
                            SharedFlag shared, ResizableFlag resizable,
-                           bool is_wasm_memory, bool free_on_destruct,
+                           bool is_wasm_memory, bool is_wasm_memory64,
                            bool has_guard_regions, bool custom_deleter,
                            bool empty_deleter)
     : buffer_start_(buffer_start),
@@ -141,8 +143,8 @@ BackingStore::BackingStore(void* buffer_start, size_t byte_length,
       is_shared_(shared == SharedFlag::kShared),
       is_resizable_by_js_(resizable == ResizableFlag::kResizable),
       is_wasm_memory_(is_wasm_memory),
+      is_wasm_memory64_(is_wasm_memory64),
       holds_shared_ptr_to_allocator_(false),
-      free_on_destruct_(free_on_destruct),
       has_guard_regions_(has_guard_regions),
       globally_registered_(false),
       custom_deleter_(custom_deleter),
@@ -150,7 +152,6 @@ BackingStore::BackingStore(void* buffer_start, size_t byte_length,
   // TODO(v8:11111): RAB / GSAB - Wasm integration.
   DCHECK_IMPLIES(is_wasm_memory_, !is_resizable_by_js_);
   DCHECK_IMPLIES(is_resizable_by_js_, !custom_deleter_);
-  DCHECK_IMPLIES(is_resizable_by_js_, free_on_destruct_);
   DCHECK_IMPLIES(!is_wasm_memory && !is_resizable_by_js_,
                  byte_length_ == max_byte_length_);
   DCHECK_GE(max_byte_length_, byte_length_);
@@ -179,11 +180,10 @@ BackingStore::~BackingStore() {
   if (buffer_start_ == nullptr) return;
 
   auto FreeResizableMemory = [this] {
-    DCHECK(free_on_destruct_);
     DCHECK(!custom_deleter_);
     DCHECK(is_resizable_by_js_ || is_wasm_memory_);
-    auto region =
-        GetReservedRegion(has_guard_regions_, buffer_start_, byte_capacity_);
+    auto region = GetReservedRegion(has_guard_regions_, is_wasm_memory64_,
+                                    buffer_start_, byte_capacity_);
 
     PageAllocator* page_allocator = GetArrayBufferPageAllocator();
     if (!region.is_empty()) {
@@ -196,8 +196,8 @@ BackingStore::~BackingStore() {
   if (is_wasm_memory_) {
     // TODO(v8:11111): RAB / GSAB - Wasm integration.
     DCHECK(!is_resizable_by_js_);
-    size_t reservation_size =
-        GetReservationSize(has_guard_regions_, byte_capacity_);
+    size_t reservation_size = GetReservationSize(
+        has_guard_regions_, byte_capacity_, is_wasm_memory64_);
     TRACE_BS(
         "BSw:free  bs=%p mem=%p (length=%zu, capacity=%zu, reservation=%zu)\n",
         this, buffer_start_, byte_length(), byte_capacity_, reservation_size);
@@ -218,7 +218,6 @@ BackingStore::~BackingStore() {
   }
 
   if (custom_deleter_) {
-    DCHECK(free_on_destruct_);
     TRACE_BS("BS:custom deleter bs=%p mem=%p (length=%zu, capacity=%zu)\n",
              this, buffer_start_, byte_length(), byte_capacity_);
     type_specific_data_.deleter.callback(buffer_start_, byte_length_,
@@ -226,13 +225,11 @@ BackingStore::~BackingStore() {
     return;
   }
 
-  if (free_on_destruct_) {
-    // JSArrayBuffer backing store. Deallocate through the embedder's allocator.
-    auto allocator = get_v8_api_array_buffer_allocator();
-    TRACE_BS("BS:free   bs=%p mem=%p (length=%zu, capacity=%zu)\n", this,
-             buffer_start_, byte_length(), byte_capacity_);
-    allocator->Free(buffer_start_, byte_length_);
-  }
+  // JSArrayBuffer backing store. Deallocate through the embedder's allocator.
+  auto allocator = get_v8_api_array_buffer_allocator();
+  TRACE_BS("BS:free   bs=%p mem=%p (length=%zu, capacity=%zu)\n", this,
+           buffer_start_, byte_length(), byte_capacity_);
+  allocator->Free(buffer_start_, byte_length_);
 }
 
 // Allocate a backing store using the array buffer allocator from the embedder.
@@ -255,18 +252,7 @@ std::unique_ptr<BackingStore> BackingStore::Allocate(
       if (initialized == InitializedFlag::kUninitialized) {
         return allocator->AllocateUninitialized(byte_length);
       }
-      void* buffer_start = allocator->Allocate(byte_length);
-      if (buffer_start) {
-        // TODO(wasm): node does not implement the zero-initialization API.
-        // Reenable this debug check when node does implement it properly.
-        constexpr bool
-            kDebugCheckZeroDisabledDueToNodeNotImplementingZeroInitAPI = true;
-        if ((!(kDebugCheckZeroDisabledDueToNodeNotImplementingZeroInitAPI)) &&
-            !v8_flags.mock_arraybuffer_allocator) {
-          DebugCheckZero(buffer_start, byte_length);
-        }
-      }
-      return buffer_start;
+      return allocator->Allocate(byte_length);
     };
 
     buffer_start = isolate->heap()->AllocateExternalBackingStore(
@@ -294,7 +280,7 @@ std::unique_ptr<BackingStore> BackingStore::Allocate(
                                  shared,                        // shared
                                  ResizableFlag::kNotResizable,  // resizable
                                  false,   // is_wasm_memory
-                                 true,    // free_on_destruct
+                                 false,   // is_wasm_memory64
                                  false,   // has_guard_regions
                                  false,   // custom_deleter
                                  false);  // empty_deleter
@@ -332,10 +318,13 @@ std::unique_ptr<BackingStore> BackingStore::TryAllocateAndPartiallyCommitMemory(
   TRACE_BS("BSw:try   %zu pages, %zu max\n", initial_pages, maximum_pages);
 
 #if V8_ENABLE_WEBASSEMBLY
-  bool guards = wasm_memory == WasmMemoryFlag::kWasmMemory32 &&
-                trap_handler::IsTrapHandlerEnabled();
+  bool is_wasm_memory64 = wasm_memory == WasmMemoryFlag::kWasmMemory64;
+  bool guards = trap_handler::IsTrapHandlerEnabled() &&
+                (wasm_memory == WasmMemoryFlag::kWasmMemory32 ||
+                 (is_wasm_memory64 && v8_flags.wasm_memory64_trap_handling));
 #else
   CHECK_EQ(WasmMemoryFlag::kNotWasm, wasm_memory);
+  constexpr bool is_wasm_memory64 = false;
   constexpr bool guards = false;
 #endif  // V8_ENABLE_WEBASSEMBLY
 
@@ -359,7 +348,8 @@ std::unique_ptr<BackingStore> BackingStore::TryAllocateAndPartiallyCommitMemory(
   };
 
   size_t byte_capacity = maximum_pages * page_size;
-  size_t reservation_size = GetReservationSize(guards, byte_capacity);
+  size_t reservation_size =
+      GetReservationSize(guards, byte_capacity, is_wasm_memory64);
 
   //--------------------------------------------------------------------------
   // Allocate pages (inaccessible by default).
@@ -383,8 +373,9 @@ std::unique_ptr<BackingStore> BackingStore::TryAllocateAndPartiallyCommitMemory(
   // Get a pointer to the start of the buffer, skipping negative guard region
   // if necessary.
 #if V8_ENABLE_WEBASSEMBLY
-  uint8_t* buffer_start = reinterpret_cast<uint8_t*>(allocation_base) +
-                          (guards ? kNegativeGuardSize : 0);
+  uint8_t* buffer_start =
+      reinterpret_cast<uint8_t*>(allocation_base) +
+      (guards && !is_wasm_memory64 ? kNegativeGuardSize : 0);
 #else
   DCHECK(!guards);
   uint8_t* buffer_start = reinterpret_cast<uint8_t*>(allocation_base);
@@ -408,8 +399,6 @@ std::unique_ptr<BackingStore> BackingStore::TryAllocateAndPartiallyCommitMemory(
     return {};
   }
 
-  DebugCheckZero(buffer_start, byte_length);  // touch the bytes.
-
   if (isolate != nullptr) {
     RecordStatus(isolate, did_retry ? AllocationStatus::kSuccessAfterRetry
                                     : AllocationStatus::kSuccess);
@@ -419,17 +408,17 @@ std::unique_ptr<BackingStore> BackingStore::TryAllocateAndPartiallyCommitMemory(
   ResizableFlag resizable =
       is_wasm_memory ? ResizableFlag::kNotResizable : ResizableFlag::kResizable;
 
-  auto result = new BackingStore(buffer_start,     // start
-                                 byte_length,      // length
-                                 max_byte_length,  // max_byte_length
-                                 byte_capacity,    // capacity
-                                 shared,           // shared
-                                 resizable,        // resizable
-                                 is_wasm_memory,   // is_wasm_memory
-                                 true,             // free_on_destruct
-                                 guards,           // has_guard_regions
-                                 false,            // custom_deleter
-                                 false);           // empty_deleter
+  auto result = new BackingStore(buffer_start,      // start
+                                 byte_length,       // length
+                                 max_byte_length,   // max_byte_length
+                                 byte_capacity,     // capacity
+                                 shared,            // shared
+                                 resizable,         // resizable
+                                 is_wasm_memory,    // is_wasm_memory
+                                 is_wasm_memory64,  // is_wasm_memory64
+                                 guards,            // has_guard_regions
+                                 false,             // custom_deleter
+                                 false);            // empty_deleter
 
   TRACE_BS(
       "BSw:alloc bs=%p mem=%p (length=%zu, capacity=%zu, reservation=%zu)\n",
@@ -570,7 +559,7 @@ base::Optional<size_t> BackingStore::GrowWasmMemoryInPlace(Isolate* isolate,
     }
   }
 
-  if (!is_shared_ && free_on_destruct_) {
+  if (!is_shared_) {
     // Only do per-isolate accounting for non-shared backing stores.
     reinterpret_cast<v8::Isolate*>(isolate)
         ->AdjustAmountOfExternalAllocatedMemory(new_length - old_length);
@@ -662,7 +651,6 @@ BackingStore::ResizeOrGrowResult BackingStore::ResizeInPlace(
   }
 
   // Do per-isolate accounting for non-shared backing stores.
-  DCHECK(free_on_destruct_);
   reinterpret_cast<v8::Isolate*>(isolate)
       ->AdjustAmountOfExternalAllocatedMemory(new_byte_length - byte_length_);
   byte_length_ = new_byte_length;
@@ -719,26 +707,6 @@ BackingStore::ResizeOrGrowResult BackingStore::GrowInPlace(
   return kSuccess;
 }
 
-std::unique_ptr<BackingStore> BackingStore::WrapAllocation(
-    Isolate* isolate, void* allocation_base, size_t allocation_length,
-    SharedFlag shared, bool free_on_destruct) {
-  auto result = new BackingStore(allocation_base,               // start
-                                 allocation_length,             // length
-                                 allocation_length,             // max length
-                                 allocation_length,             // capacity
-                                 shared,                        // shared
-                                 ResizableFlag::kNotResizable,  // resizable
-                                 false,             // is_wasm_memory
-                                 free_on_destruct,  // free_on_destruct
-                                 false,             // has_guard_regions
-                                 false,             // custom_deleter
-                                 false);            // empty_deleter
-  result->SetAllocatorFromIsolate(isolate);
-  TRACE_BS("BS:wrap   bs=%p mem=%p (length=%zu)\n", result,
-           result->buffer_start(), result->byte_length());
-  return std::unique_ptr<BackingStore>(result);
-}
-
 std::unique_ptr<BackingStore> BackingStore::WrapAllocation(
     void* allocation_base, size_t allocation_length,
     v8::BackingStore::DeleterCallback deleter, void* deleter_data,
@@ -751,7 +719,7 @@ std::unique_ptr<BackingStore> BackingStore::WrapAllocation(
                                  shared,                        // shared
                                  ResizableFlag::kNotResizable,  // resizable
                                  false,              // is_wasm_memory
-                                 true,               // free_on_destruct
+                                 false,              // is_wasm_memory64
                                  false,              // has_guard_regions
                                  true,               // custom_deleter
                                  is_empty_deleter);  // empty_deleter
@@ -770,7 +738,7 @@ std::unique_ptr<BackingStore> BackingStore::EmptyBackingStore(
                                  shared,                        // shared
                                  ResizableFlag::kNotResizable,  // resizable
                                  false,   // is_wasm_memory
-                                 true,    // free_on_destruct
+                                 false,   // is_wasm_memory64
                                  false,   // has_guard_regions
                                  false,   // custom_deleter
                                  false);  // empty_deleter
