@@ -25,20 +25,13 @@ const {
   ArrayIsArray,
   Boolean,
   Error,
-  FunctionPrototypeCall,
   NumberIsFinite,
   ObjectAssign,
   ObjectKeys,
   ObjectSetPrototypeOf,
   ReflectApply,
-  RegExpPrototypeExec,
   String,
-  StringPrototypeCharCodeAt,
-  StringPrototypeIncludes,
-  StringPrototypeIndexOf,
-  StringPrototypeToUpperCase,
   Symbol,
-  TypedArrayPrototypeSlice,
 } = primordials;
 
 const net = require('net');
@@ -72,14 +65,16 @@ const {
   traceEnd,
   getNextTraceEventId,
 } = require('internal/http');
-const { ConnResetException, codes } = require('internal/errors');
 const {
-  ERR_HTTP_HEADERS_SENT,
-  ERR_INVALID_ARG_TYPE,
-  ERR_INVALID_HTTP_TOKEN,
-  ERR_INVALID_PROTOCOL,
-  ERR_UNESCAPED_CHARACTERS,
-} = codes;
+  ConnResetException,
+  codes: {
+    ERR_HTTP_HEADERS_SENT,
+    ERR_INVALID_ARG_TYPE,
+    ERR_INVALID_HTTP_TOKEN,
+    ERR_INVALID_PROTOCOL,
+    ERR_UNESCAPED_CHARACTERS,
+  },
+} = require('internal/errors');
 const {
   validateInteger,
   validateBoolean,
@@ -128,7 +123,7 @@ class HTTPClientAsyncResource {
 }
 
 function ClientRequest(input, options, cb) {
-  FunctionPrototypeCall(OutgoingMessage, this);
+  OutgoingMessage.call(this);
 
   if (typeof input === 'string') {
     const urlStr = input;
@@ -173,7 +168,7 @@ function ClientRequest(input, options, cb) {
 
   if (options.path) {
     const path = String(options.path);
-    if (RegExpPrototypeExec(INVALID_PATH_REGEX, path) !== null) {
+    if (INVALID_PATH_REGEX.test(path)) {
       debug('Path contains unescaped characters: "%s"', path);
       throw new ERR_UNESCAPED_CHARACTERS('Request path');
     }
@@ -214,7 +209,7 @@ function ClientRequest(input, options, cb) {
     if (!checkIsHttpToken(method)) {
       throw new ERR_INVALID_HTTP_TOKEN('Method', method);
     }
-    method = this.method = StringPrototypeToUpperCase(method);
+    method = this.method = method.toUpperCase();
   } else {
     method = this.method = 'GET';
   }
@@ -296,10 +291,10 @@ function ClientRequest(input, options, cb) {
       // For the Host header, ensure that IPv6 addresses are enclosed
       // in square brackets, as defined by URI formatting
       // https://tools.ietf.org/html/rfc3986#section-3.2.2
-      const posColon = StringPrototypeIndexOf(hostHeader, ':');
+      const posColon = hostHeader.indexOf(':');
       if (posColon !== -1 &&
-          StringPrototypeIncludes(hostHeader, ':', posColon + 1) &&
-          StringPrototypeCharCodeAt(hostHeader, 0) !== 91/* '[' */) {
+          hostHeader.includes(':', posColon + 1) &&
+          hostHeader.charCodeAt(0) !== 91/* '[' */) {
         hostHeader = `[${hostHeader}]`;
       }
 
@@ -336,7 +331,16 @@ function ClientRequest(input, options, cb) {
     // No agent, default to Connection:close.
     this._last = true;
     this.shouldKeepAlive = false;
-    if (typeof optsWithoutSignal.createConnection === 'function') {
+    let opts = optsWithoutSignal;
+    if (opts.path || opts.socketPath) {
+      opts = { ...optsWithoutSignal };
+      if (opts.socketPath) {
+        opts.path = opts.socketPath;
+      } else if (opts.path) {
+        opts.path = undefined;
+      }
+    }
+    if (typeof opts.createConnection === 'function') {
       const oncreate = once((err, socket) => {
         if (err) {
           process.nextTick(() => this.emit('error', err));
@@ -346,8 +350,7 @@ function ClientRequest(input, options, cb) {
       });
 
       try {
-        const newSocket = optsWithoutSignal.createConnection(optsWithoutSignal,
-                                                             oncreate);
+        const newSocket = opts.createConnection(opts, oncreate);
         if (newSocket) {
           oncreate(null, newSocket);
         }
@@ -355,8 +358,8 @@ function ClientRequest(input, options, cb) {
         oncreate(err);
       }
     } else {
-      debug('CLIENT use net.createConnection', optsWithoutSignal);
-      this.onSocket(net.createConnection(optsWithoutSignal));
+      debug('CLIENT use net.createConnection', opts);
+      this.onSocket(net.createConnection(opts));
     }
   }
 }
@@ -364,7 +367,7 @@ ObjectSetPrototypeOf(ClientRequest.prototype, OutgoingMessage.prototype);
 ObjectSetPrototypeOf(ClientRequest, OutgoingMessage);
 
 ClientRequest.prototype._finish = function _finish() {
-  FunctionPrototypeCall(OutgoingMessage.prototype._finish, this);
+  OutgoingMessage.prototype._finish.call(this);
   if (hasObserver('http')) {
     startPerf(this, kClientRequestStatistics, {
       type: 'http',
@@ -555,7 +558,7 @@ function socketOnData(d) {
     parser.finish();
     freeParser(parser, req, socket);
 
-    const bodyHead = TypedArrayPrototypeSlice(d, bytesParsed, d.length);
+    const bodyHead = d.slice(bytesParsed, d.length);
 
     const eventName = req.method === 'CONNECT' ? 'connect' : 'upgrade';
     if (req.listenerCount(eventName) > 0) {
