@@ -22,19 +22,11 @@
 'use strict';
 
 const {
-  ArrayPrototypeForEach,
-  ArrayPrototypeJoin,
-  ArrayPrototypePush,
-  FunctionPrototype,
   ObjectAssign,
   ObjectDefineProperty,
   ObjectSetPrototypeOf,
   ReflectApply,
   RegExp,
-  RegExpPrototypeExec,
-  RegExpPrototypeSymbolReplace,
-  StringPrototypeReplaceAll,
-  StringPrototypeSlice,
   Symbol,
   SymbolFor,
 } = primordials;
@@ -119,7 +111,7 @@ const kPskIdentityHint = Symbol('pskidentityhint');
 const kPendingSession = Symbol('pendingSession');
 const kIsVerified = Symbol('verified');
 
-const noop = FunctionPrototype;
+const noop = () => {};
 
 let ipServernameWarned = false;
 let tlsTracingWarned = false;
@@ -475,8 +467,7 @@ function onerror(err) {
     owner.destroy(err);
   } else if (owner._tlsOptions?.isServer &&
              owner._rejectUnauthorized &&
-             RegExpPrototypeExec(/peer did not return a certificate/,
-                                 err.message) !== null) {
+             /peer did not return a certificate/.test(err.message)) {
     // Ignore server's authorization errors
     owner.destroy();
   } else {
@@ -1153,6 +1144,17 @@ TLSSocket.prototype.getX509Certificate = function() {
   return cert ? new InternalX509Certificate(cert) : undefined;
 };
 
+TLSSocket.prototype.setKeyCert = function(context) {
+  if (this._handle) {
+    let secureContext;
+    if (context instanceof common.SecureContext)
+      secureContext = context;
+    else
+      secureContext = tls.createSecureContext(context);
+    this._handle.setKeyCert(secureContext.context);
+  }
+};
+
 // Proxy TLSSocket handle methods
 function makeSocketMethodProxy(name) {
   return function socketMethodProxy(...args) {
@@ -1162,7 +1164,7 @@ function makeSocketMethodProxy(name) {
   };
 }
 
-ArrayPrototypeForEach([
+[
   'getCipher',
   'getSharedSigalgs',
   'getEphemeralKeyInfo',
@@ -1173,7 +1175,7 @@ ArrayPrototypeForEach([
   'getTLSTicket',
   'isSessionReused',
   'enableTrace',
-], (method) => {
+].forEach((method) => {
   TLSSocket.prototype[method] = makeSocketMethodProxy(method);
 });
 
@@ -1470,10 +1472,10 @@ Server.prototype.setSecureContext = function(options) {
   if (options.sessionIdContext) {
     this.sessionIdContext = options.sessionIdContext;
   } else {
-    this.sessionIdContext = StringPrototypeSlice(
-      crypto.createHash('sha1')
-        .update(ArrayPrototypeJoin(process.argv, ' '))
-        .digest('hex'), 0, 32);
+    this.sessionIdContext = crypto.createHash('sha1')
+      .update(process.argv.join(' '))
+      .digest('hex')
+      .slice(0, 32);
   }
 
   if (options.sessionTimeout)
@@ -1568,10 +1570,10 @@ Server.prototype.setOptions = deprecate(function(options) {
   if (options.sessionIdContext) {
     this.sessionIdContext = options.sessionIdContext;
   } else {
-    this.sessionIdContext = StringPrototypeSlice(
-      crypto.createHash('sha1')
-        .update(ArrayPrototypeJoin(process.argv, ' '))
-        .digest('hex'), 0, 32);
+    this.sessionIdContext = crypto.createHash('sha1')
+      .update(process.argv.join(' '))
+      .digest('hex')
+      .slice(0, 32);
   }
   if (options.pskCallback) this[kPskCallback] = options.pskCallback;
   if (options.pskIdentityHint) this[kPskIdentityHint] = options.pskIdentityHint;
@@ -1588,14 +1590,15 @@ Server.prototype.addContext = function(servername, context) {
     throw new ERR_TLS_REQUIRED_SERVER_NAME();
   }
 
-  const re = new RegExp('^' + StringPrototypeReplaceAll(
-    RegExpPrototypeSymbolReplace(/([.^$+?\-\\[\]{}])/g, servername, '\\$1'),
-    '*', '[^.]*',
-  ) + '$');
+  const re = new RegExp(`^${
+    servername
+      .replace(/([.^$+?\-\\[\]{}])/g, '\\$1')
+      .replaceAll('*', '[^.]*')
+  }$`);
 
   const secureContext =
     context instanceof common.SecureContext ? context : tls.createSecureContext(context);
-  ArrayPrototypePush(this._contexts, [re, secureContext.context]);
+  this._contexts.push([re, secureContext.context]);
 };
 
 Server.prototype[EE.captureRejectionSymbol] = function(
@@ -1616,7 +1619,7 @@ function SNICallback(servername, callback) {
 
   for (let i = contexts.length - 1; i >= 0; --i) {
     const elem = contexts[i];
-    if (RegExpPrototypeExec(elem[0], servername) !== null) {
+    if (elem[0].test(servername)) {
       callback(null, elem[1]);
       return;
     }
