@@ -25,10 +25,10 @@ const {
 
 const {
   codes: {
-    ERR_INVALID_ARG_TYPE,
     ERR_EVENT_RECURSION,
-    ERR_MISSING_ARGS,
+    ERR_INVALID_ARG_TYPE,
     ERR_INVALID_THIS,
+    ERR_MISSING_ARGS,
   },
 } = require('internal/errors');
 const {
@@ -36,8 +36,7 @@ const {
   validateObject,
   validateString,
   validateInternalField,
-  kValidateObjectAllowArray,
-  kValidateObjectAllowFunction,
+  kValidateObjectAllowObjects,
 } = require('internal/validators');
 
 const {
@@ -66,7 +65,7 @@ const kWeakHandler = Symbol('kWeak');
 const kResistStopPropagation = Symbol('kResistStopPropagation');
 
 const kHybridDispatch = SymbolFor('nodejs.internal.kHybridDispatch');
-const kRemoveWeakListenerHelper = Symbol('nodejs.internal.removeWeakListenerHelper');
+const kRemoveWeakListenerHelper = Symbol('kRemoveWeakListenerHelper');
 const kCreateEvent = Symbol('kCreateEvent');
 const kNewListener = Symbol('kNewListener');
 const kRemoveListener = Symbol('kRemoveListener');
@@ -169,6 +168,10 @@ class Event {
   stopImmediatePropagation() {
     if (!isEvent(this))
       throw new ERR_INVALID_THIS('Event');
+    // Spec mention "stopImmediatePropagation should set both "stop propagation"
+    // and "stop immediate propagation" flags"
+    // cf: from https://dom.spec.whatwg.org/#dom-event-stopimmediatepropagation
+    this.stopPropagation();
     this[kStop] = true;
   }
 
@@ -306,7 +309,7 @@ class Event {
     if (!isEvent(this))
       throw new ERR_INVALID_THIS('Event');
     if (value) {
-      this.stopPropagation();
+      this.#propagationStopped = true;
     }
   }
 
@@ -409,15 +412,6 @@ ObjectDefineProperties(CustomEvent.prototype, {
   detail: kEnumerableProperty,
 });
 
-class NodeCustomEvent extends Event {
-  constructor(type, options) {
-    super(type, options);
-    if (options?.detail) {
-      this.detail = options.detail;
-    }
-  }
-}
-
 // Weak listener cleanup
 // This has to be lazy for snapshots to work
 let weakListenersState = null;
@@ -567,7 +561,7 @@ class EventTarget {
       // eslint-disable-next-line no-restricted-syntax
       const w = new Error('Possible EventTarget memory leak detected. ' +
                           `${size} ${type} listeners ` +
-                          `added to ${inspect(this, { depth: -1 })}. Use ` +
+                          `added to ${inspect(this, { depth: -1 })}. MaxListeners is ${this[kMaxEventTargetListeners]}. Use ` +
                           'events.setMaxListeners() to increase limit');
       w.name = 'MaxListenersExceededWarning';
       w.target = this;
@@ -838,7 +832,7 @@ class EventTarget {
   }
 
   [kCreateEvent](nodeValue, type) {
-    return new NodeCustomEvent(type, { detail: nodeValue });
+    return new CustomEvent(type, { detail: nodeValue });
   }
   [customInspectSymbol](depth, options) {
     if (!isEventTarget(this))
@@ -1056,7 +1050,7 @@ function validateEventListenerOptions(options) {
 
   if (options === null)
     return kEmptyObject;
-  validateObject(options, 'options', kValidateObjectAllowArray | kValidateObjectAllowFunction);
+  validateObject(options, 'options', kValidateObjectAllowObjects);
   return {
     once: Boolean(options.once),
     capture: Boolean(options.capture),
