@@ -27,17 +27,14 @@ const { BuiltinModule } = require('internal/bootstrap/realm');
 const { realpathSync } = require('fs');
 const { getOptionValue } = require('internal/options');
 // Do not eagerly grab .manifest, it may be in TDZ
-const policy = getOptionValue('--experimental-policy') ?
-  require('internal/process/policy') :
-  null;
-const { sep, posix: { relative: relativePosixPath }, toNamespacedPath, resolve } = require('path');
+const { sep, posix: { relative: relativePosixPath }, resolve } = require('path');
 const preserveSymlinks = getOptionValue('--preserve-symlinks');
 const preserveSymlinksMain = getOptionValue('--preserve-symlinks-main');
 const experimentalNetworkImports =
   getOptionValue('--experimental-network-imports');
 const inputTypeFlag = getOptionValue('--input-type');
-const { URL, pathToFileURL, fileURLToPath, isURL } = require('internal/url');
-const { getCWDURL } = require('internal/util');
+const { URL, pathToFileURL, fileURLToPath, isURL, URLParse } = require('internal/url');
+const { getCWDURL, setOwnProperty } = require('internal/util');
 const { canParse: URLCanParse } = internalBinding('url');
 const { legacyMainResolve: FSLegacyMainResolve } = internalBinding('fs');
 const {
@@ -46,18 +43,18 @@ const {
   ERR_INVALID_MODULE_SPECIFIER,
   ERR_INVALID_PACKAGE_CONFIG,
   ERR_INVALID_PACKAGE_TARGET,
-  ERR_MANIFEST_DEPENDENCY_MISSING,
   ERR_MODULE_NOT_FOUND,
   ERR_PACKAGE_IMPORT_NOT_DEFINED,
   ERR_PACKAGE_PATH_NOT_EXPORTED,
   ERR_UNSUPPORTED_DIR_IMPORT,
+  ERR_UNSUPPORTED_RESOLVE_REQUEST,
   ERR_NETWORK_IMPORT_DISALLOWED,
 } = require('internal/errors').codes;
 
 const { Module: CJSModule } = require('internal/modules/cjs/loader');
 const { getConditionsSet } = require('internal/modules/esm/utils');
 const packageJsonReader = require('internal/modules/package_json_reader');
-const { internalModuleStat } = internalBinding('fs');
+const internalFsBinding = internalBinding('fs');
 
 /**
  * @typedef {import('internal/modules/esm/package_config.js').PackageConfig} PackageConfig
@@ -249,8 +246,8 @@ function finalizeResolution(resolved, base, preserveSymlinks) {
     throw err;
   }
 
-  const stats = internalModuleStat(toNamespacedPath(StringPrototypeEndsWith(path, '/') ?
-    StringPrototypeSlice(path, -1) : path));
+  const stats = internalFsBinding.internalModuleStat(StringPrototypeEndsWith(path, '/') ?
+    StringPrototypeSlice(path, -1) : path);
 
   // Check for stats.isDirectory()
   if (stats === 1) {
@@ -809,8 +806,9 @@ function packageResolve(specifier, base, conditions) {
   let packageJSONPath = fileURLToPath(packageJSONUrl);
   let lastPath;
   do {
-    const stat = internalModuleStat(toNamespacedPath(StringPrototypeSlice(packageJSONPath, 0,
-                                                                          packageJSONPath.length - 13)));
+    const stat = internalFsBinding.internalModuleStat(
+      StringPrototypeSlice(packageJSONPath, 0, packageJSONPath.length - 13),
+    );
     // Check for !stat.isDirectory()
     if (stat !== 1) {
       lastPath = packageJSONPath;
@@ -884,22 +882,37 @@ function shouldBeTreatedAsRelativeOrAbsolutePath(specifier) {
  * @param {boolean} preserveSymlinks - Whether to preserve symlinks in the resolved URL.
  */
 function moduleResolve(specifier, base, conditions, preserveSymlinks) {
-  const isRemote = base.protocol === 'http:' ||
-    base.protocol === 'https:';
+  const protocol = typeof base === 'string' ?
+    StringPrototypeSlice(base, 0, StringPrototypeIndexOf(base, ':') + 1) :
+    base.protocol;
+  const isData = protocol === 'data:';
+  const isRemote =
+    isData ||
+    protocol === 'http:' ||
+    protocol === 'https:';
   // Order swapped from spec for minor perf gain.
   // Ok since relative URLs cannot parse as URLs.
   let resolved;
   if (shouldBeTreatedAsRelativeOrAbsolutePath(specifier)) {
-    resolved = new URL(specifier, base);
-  } else if (!isRemote && specifier[0] === '#') {
+    try {
+      resolved = new URL(specifier, base);
+    } catch (cause) {
+      const error = new ERR_UNSUPPORTED_RESOLVE_REQUEST(specifier, base);
+      setOwnProperty(error, 'cause', cause);
+      throw error;
+    }
+  } else if (protocol === 'file:' && specifier[0] === '#') {
     resolved = packageImportsResolve(specifier, base, conditions);
   } else {
     try {
       resolved = new URL(specifier);
-    } catch {
-      if (!isRemote) {
-        resolved = packageResolve(specifier, base, conditions);
+    } catch (cause) {
+      if (isRemote && !BuiltinModule.canBeRequiredWithoutScheme(specifier)) {
+        const error = new ERR_UNSUPPORTED_RESOLVE_REQUEST(specifier, base);
+        setOwnProperty(error, 'cause', cause);
+        throw error;
       }
+      resolved = packageResolve(specifier, base, conditions);
     }
   }
   if (resolved.protocol !== 'file:') {
@@ -1029,8 +1042,7 @@ function throwIfInvalidParentURL(parentURL) {
 
 /**
  * Resolves the given specifier using the provided context, which includes the parent URL and conditions.
- * Throws an error if the parent URL is invalid or if the resolution is disallowed by the policy manifest.
- * Otherwise, attempts to resolve the specifier and returns the resulting URL and format.
+ * Attempts to resolve the specifier and returns the resulting URL and format.
  * @param {string} specifier - The specifier to resolve.
  * @param {object} [context={}] - The context object containing the parent URL and conditions.
  * @param {string} [context.parentURL] - The URL of the parent module.
@@ -1039,50 +1051,32 @@ function throwIfInvalidParentURL(parentURL) {
 function defaultResolve(specifier, context = {}) {
   let { parentURL, conditions } = context;
   throwIfInvalidParentURL(parentURL);
-  if (parentURL && policy?.manifest) {
-    const redirects = policy.manifest.getDependencyMapper(parentURL);
-    if (redirects) {
-      const { resolve, reaction } = redirects;
-      const destination = resolve(specifier, new SafeSet(conditions));
-      let missing = true;
-      if (destination === true) {
-        missing = false;
-      } else if (destination) {
-        const href = destination.href;
-        return { __proto__: null, url: href };
-      }
-      if (missing) {
-        // Prevent network requests from firing if resolution would be banned.
-        // Network requests can extract data by doing things like putting
-        // secrets in query params
-        reaction(new ERR_MANIFEST_DEPENDENCY_MISSING(
-          parentURL,
-          specifier,
-          ArrayPrototypeJoin([...conditions], ', ')),
-        );
-      }
-    }
-  }
 
   let parsedParentURL;
   if (parentURL) {
-    try {
-      parsedParentURL = new URL(parentURL);
-    } catch {
-      // Ignore exception
-    }
+    parsedParentURL = URLParse(parentURL);
   }
 
-  let parsed;
-  try {
-    if (shouldBeTreatedAsRelativeOrAbsolutePath(specifier)) {
-      parsed = new URL(specifier, parsedParentURL);
-    } else {
-      parsed = new URL(specifier);
-    }
+  let parsed, protocol;
+  if (shouldBeTreatedAsRelativeOrAbsolutePath(specifier)) {
+    parsed = URLParse(specifier, parsedParentURL);
+  } else {
+    parsed = URLParse(specifier);
+  }
 
+  if (parsed != null) {
     // Avoid accessing the `protocol` property due to the lazy getters.
-    const protocol = parsed.protocol;
+    protocol = parsed.protocol;
+
+    if (protocol === 'data:' &&
+      parsedParentURL.protocol !== 'file:' &&
+      experimentalNetworkImports) {
+      throw new ERR_NETWORK_IMPORT_DISALLOWED(
+        specifier,
+        parsedParentURL,
+        'import data: from a non file: is not allowed',
+      );
+    }
     if (protocol === 'data:' ||
       (experimentalNetworkImports &&
         (
@@ -1093,8 +1087,6 @@ function defaultResolve(specifier, context = {}) {
     ) {
       return { __proto__: null, url: parsed.href };
     }
-  } catch {
-    // Ignore exception
   }
 
   // There are multiple deep branches that can either throw or return; instead
@@ -1109,7 +1101,8 @@ function defaultResolve(specifier, context = {}) {
   if (maybeReturn) { return maybeReturn; }
 
   // This must come after checkIfDisallowedImport
-  if (parsed && parsed.protocol === 'node:') { return { __proto__: null, url: specifier }; }
+  protocol ??= parsed?.protocol;
+  if (protocol === 'node:') { return { __proto__: null, url: specifier }; }
 
 
   const isMain = parentURL === undefined;
@@ -1190,22 +1183,3 @@ module.exports = {
 const {
   defaultGetFormatWithoutErrors,
 } = require('internal/modules/esm/get_format');
-
-if (policy) {
-  const $defaultResolve = defaultResolve;
-  module.exports.defaultResolve = function defaultResolve(
-    specifier,
-    context,
-  ) {
-    const ret = $defaultResolve(specifier, context);
-    // This is a preflight check to avoid data exfiltration by query params etc.
-    policy.manifest.mightAllow(ret.url, () =>
-      new ERR_MANIFEST_DEPENDENCY_MISSING(
-        context.parentURL,
-        specifier,
-        context.conditions,
-      ),
-    );
-    return ret;
-  };
-}
