@@ -7,13 +7,8 @@ const {
   StringPrototypeSlice,
   StringPrototypeToUpperCase,
   Symbol,
-  globalThis,
 } = primordials;
 
-const {
-  Intl,
-} = globalThis;
-
 const {
   ERR_ILLEGAL_CONSTRUCTOR,
 } = require('internal/errors').codes;
@@ -27,61 +22,68 @@ const {
 } = internalBinding('os');
 
 const kInitialize = Symbol('kInitialize');
-const nodeVersion = process.version;
+
+const {
+  platform,
+  arch,
+  version: nodeVersion,
+} = require('internal/process/per_thread');
+
+const {
+  language,
+} = internalBinding('config');
 
 /**
- * @param {object} process
- * @param {string} process.platform
- * @param {string} process.arch
+ * @param {string} arch
+ * @param {string} platform
  * @returns {string}
  */
-function getNavigatorPlatform(process) {
-  if (process.platform === 'darwin') {
+function getNavigatorPlatform(arch, platform) {
+  if (platform === 'darwin') {
     // On macOS, modern browsers return 'MacIntel' even if running on Apple Silicon.
     return 'MacIntel';
-  } else if (process.platform === 'win32') {
+  } else if (platform === 'win32') {
     // On Windows, modern browsers return 'Win32' even if running on a 64-bit version of Windows.
     // https://developer.mozilla.org/en-US/docs/Web/API/Navigator/platform#usage_notes
     return 'Win32';
-  } else if (process.platform === 'linux') {
-    if (process.arch === 'ia32') {
+  } else if (platform === 'linux') {
+    if (arch === 'ia32') {
       return 'Linux i686';
-    } else if (process.arch === 'x64') {
+    } else if (arch === 'x64') {
       return 'Linux x86_64';
     }
-    return `Linux ${process.arch}`;
-  } else if (process.platform === 'freebsd') {
-    if (process.arch === 'ia32') {
+    return `Linux ${arch}`;
+  } else if (platform === 'freebsd') {
+    if (arch === 'ia32') {
       return 'FreeBSD i386';
-    } else if (process.arch === 'x64') {
+    } else if (arch === 'x64') {
       return 'FreeBSD amd64';
     }
-    return `FreeBSD ${process.arch}`;
-  } else if (process.platform === 'openbsd') {
-    if (process.arch === 'ia32') {
+    return `FreeBSD ${arch}`;
+  } else if (platform === 'openbsd') {
+    if (arch === 'ia32') {
       return 'OpenBSD i386';
-    } else if (process.arch === 'x64') {
+    } else if (arch === 'x64') {
       return 'OpenBSD amd64';
     }
-    return `OpenBSD ${process.arch}`;
-  } else if (process.platform === 'sunos') {
-    if (process.arch === 'ia32') {
+    return `OpenBSD ${arch}`;
+  } else if (platform === 'sunos') {
+    if (arch === 'ia32') {
       return 'SunOS i86pc';
     }
-    return `SunOS ${process.arch}`;
-  } else if (process.platform === 'aix') {
+    return `SunOS ${arch}`;
+  } else if (platform === 'aix') {
     return 'AIX';
   }
-  return `${StringPrototypeToUpperCase(process.platform[0])}${StringPrototypeSlice(process.platform, 1)} ${process.arch}`;
+  return `${StringPrototypeToUpperCase(platform[0])}${StringPrototypeSlice(platform, 1)} ${arch}`;
 }
 
 class Navigator {
   // Private properties are used to avoid brand validations.
   #availableParallelism;
-  #userAgent = `Node.js/${StringPrototypeSlice(nodeVersion, 1, StringPrototypeIndexOf(nodeVersion, '.'))}`;
-  #platform = getNavigatorPlatform(process);
-  #language = Intl?.Collator().resolvedOptions().locale || 'en-US';
-  #languages = ObjectFreeze([this.#language]);
+  #userAgent;
+  #platform;
+  #languages;
 
   constructor() {
     if (arguments[0] === kInitialize) {
@@ -102,13 +104,14 @@ class Navigator {
    * @return {string}
    */
   get language() {
-    return this.#language;
+    return language;
   }
 
   /**
    * @return {Array<string>}
    */
   get languages() {
+    this.#languages ??= ObjectFreeze([this.language]);
     return this.#languages;
   }
 
@@ -116,6 +119,7 @@ class Navigator {
    * @return {string}
    */
   get userAgent() {
+    this.#userAgent ??= `Node.js/${StringPrototypeSlice(nodeVersion, 1, StringPrototypeIndexOf(nodeVersion, '.'))}`;
     return this.#userAgent;
   }
 
@@ -123,6 +127,7 @@ class Navigator {
    * @return {string}
    */
   get platform() {
+    this.#platform ??= getNavigatorPlatform(arch, platform);
     return this.#platform;
   }
 }
