@@ -13,7 +13,6 @@ const {
   ObjectDefineProperty,
   ObjectFreeze,
   ObjectGetOwnPropertyDescriptor,
-  SafeMap,
   String,
   StringPrototypeStartsWith,
   Symbol,
@@ -22,6 +21,10 @@ const {
   globalThis,
 } = primordials;
 
+const {
+  Intl,
+} = globalThis;
+
 const {
   getOptionValue,
   refreshOptions,
@@ -37,7 +40,6 @@ const {
 
 const {
   ERR_INVALID_THIS,
-  ERR_MANIFEST_ASSERT_INTEGRITY,
   ERR_NO_CRYPTO,
   ERR_MISSING_OPTION,
   ERR_ACCESS_DENIED,
@@ -61,7 +63,7 @@ function prepareMainThreadExecution(expandArgv1 = false, initializeModules = tru
 function prepareWorkerThreadExecution() {
   prepareExecution({
     expandArgv1: false,
-    initializeModules: false,  // Will need to initialize it after policy setup
+    initializeModules: false,
     isMainThread: false,
   });
 }
@@ -108,7 +110,10 @@ function prepareExecution(options) {
   setupWarningHandler();
   setupUndici();
   setupWebCrypto();
+  setupSQLite();
+  setupWebStorage();
   setupCustomEvent();
+  setupEventsource();
   setupCodeCoverage();
   setupDebugEnv();
   // Process initial diagnostic reporting configuration, if present.
@@ -127,11 +132,6 @@ function prepareExecution(options) {
   if (isMainThread) {
     assert(internalBinding('worker').isMainThread);
     // Worker threads will get the manifest in the message handler.
-    const policy = readPolicyFromDisk();
-    if (policy) {
-      require('internal/process/policy')
-        .setup(policy.manifestSrc, policy.manifestURL);
-    }
 
     // Print stack trace on `SIGINT` if option `--trace-sigint` presents.
     setupStacktracePrinterOnSigint();
@@ -197,6 +197,9 @@ function setupUserModules(forceDefaultLoader = false) {
   } = require('internal/modules/helpers');
   assert(!hasStartedUserCJSExecution());
   assert(!hasStartedUserESMExecution());
+  if (getEmbedderOptions().hasEmbedderPreload) {
+    runEmbedderPreload();
+  }
   // Do not enable preload modules if custom loaders are disabled.
   // For example, loader workers are responsible for doing this themselves.
   // And preload modules are not supported in ShadowRealm as well.
@@ -320,8 +323,15 @@ function setupUndici() {
     delete globalThis.Response;
   }
 
-  if (!getEmbedderOptions().noBrowserGlobals && getOptionValue('--experimental-websocket')) {
-    exposeLazyInterfaces(globalThis, 'internal/deps/undici/undici', ['WebSocket']);
+  if (getOptionValue('--no-experimental-websocket')) {
+    delete globalThis.WebSocket;
+  }
+}
+
+// https://html.spec.whatwg.org/multipage/server-sent-events.html
+function setupEventsource() {
+  if (!getOptionValue('--experimental-eventsource')) {
+    delete globalThis.EventSource;
   }
 }
 
@@ -335,6 +345,7 @@ function setupNavigator() {
 
   // https://html.spec.whatwg.org/multipage/system-state.html#the-navigator-object
   exposeLazyInterfaces(globalThis, 'internal/navigator', ['Navigator']);
+  internalBinding('config').language = Intl?.Collator().resolvedOptions().locale || 'en-US';
   defineReplaceableLazyAttribute(globalThis, 'internal/navigator', ['navigator'], false);
 }
 
@@ -373,6 +384,28 @@ function setupWebCrypto() {
   }
 }
 
+function setupSQLite() {
+  if (!getOptionValue('--experimental-sqlite')) {
+    return;
+  }
+
+  const { BuiltinModule } = require('internal/bootstrap/realm');
+  BuiltinModule.allowRequireByUsers('sqlite');
+}
+
+function setupWebStorage() {
+  if (getEmbedderOptions().noBrowserGlobals ||
+      !getOptionValue('--experimental-webstorage')) {
+    return;
+  }
+
+  // https://html.spec.whatwg.org/multipage/webstorage.html#webstorage
+  exposeLazyInterfaces(globalThis, 'internal/webstorage', ['Storage']);
+  defineReplaceableLazyAttribute(globalThis, 'internal/webstorage', [
+    'localStorage', 'sessionStorage',
+  ]);
+}
+
 function setupCodeCoverage() {
   // Resolve the coverage directory to an absolute path, and
   // overwrite process.env so that the original path gets passed
@@ -582,10 +615,11 @@ function initializePermission() {
     ObjectFreeze(require('path'));
     process.emitWarning('Permission is an experimental feature',
                         'ExperimentalWarning');
-    const { has, deny } = require('internal/process/permission');
+    const { has } = require('internal/process/permission');
     const warnFlags = [
       '--allow-addons',
       '--allow-child-process',
+      '--allow-wasi',
       '--allow-worker',
     ];
     for (const flag of warnFlags) {
@@ -618,7 +652,6 @@ function initializePermission() {
       configurable: false,
       value: {
         has,
-        deny,
       },
     });
   } else {
@@ -627,6 +660,7 @@ function initializePermission() {
       '--allow-fs-write',
       '--allow-addons',
       '--allow-child-process',
+      '--allow-wasi',
       '--allow-worker',
     ];
     ArrayPrototypeForEach(availablePermissionFlags, (flag) => {
@@ -638,56 +672,6 @@ function initializePermission() {
   }
 }
 
-function readPolicyFromDisk() {
-  const experimentalPolicy = getOptionValue('--experimental-policy');
-  if (experimentalPolicy) {
-    process.emitWarning('Policies are experimental.',
-                        'ExperimentalWarning');
-    const { pathToFileURL, URL } = require('internal/url');
-    // URL here as it is slightly different parsing
-    // no bare specifiers for now
-    let manifestURL;
-    if (require('path').isAbsolute(experimentalPolicy)) {
-      manifestURL = pathToFileURL(experimentalPolicy);
-    } else {
-      const cwdURL = pathToFileURL(process.cwd());
-      cwdURL.pathname += '/';
-      manifestURL = new URL(experimentalPolicy, cwdURL);
-    }
-    const fs = require('fs');
-    const src = fs.readFileSync(manifestURL, 'utf8');
-    const experimentalPolicyIntegrity = getOptionValue('--policy-integrity');
-    if (experimentalPolicyIntegrity) {
-      const SRI = require('internal/policy/sri');
-      const { createHash, timingSafeEqual } = require('crypto');
-      const realIntegrities = new SafeMap();
-      const integrityEntries = SRI.parse(experimentalPolicyIntegrity);
-      let foundMatch = false;
-      for (let i = 0; i < integrityEntries.length; i++) {
-        const {
-          algorithm,
-          value: expected,
-        } = integrityEntries[i];
-        const hash = createHash(algorithm);
-        hash.update(src);
-        const digest = hash.digest();
-        if (digest.length === expected.length &&
-          timingSafeEqual(digest, expected)) {
-          foundMatch = true;
-          break;
-        }
-        realIntegrities.set(algorithm, digest.toString('base64'));
-      }
-      if (!foundMatch) {
-        throw new ERR_MANIFEST_ASSERT_INTEGRITY(manifestURL, realIntegrities);
-      }
-    }
-    return {
-      manifestSrc: src, manifestURL: manifestURL.href,
-    };
-  }
-}
-
 function initializeCJSLoader() {
   const { initializeCJS } = require('internal/modules/cjs/loader');
   initializeCJS();
@@ -725,6 +709,10 @@ function initializeFrozenIntrinsics() {
   }
 }
 
+function runEmbedderPreload() {
+  internalBinding('mksnapshot').runEmbedderPreload(process, require);
+}
+
 function loadPreloadModules() {
   // For user code, we preload modules if `-r` is passed
   const preloadModules = getOptionValue('--require');
