@@ -46,8 +46,13 @@ const {
   kEnumerableProperty,
   kEmptyObject,
   SideEffectFreeRegExpPrototypeSymbolReplace,
+  isWindows,
 } = require('internal/util');
 
+const {
+  platform,
+} = require('internal/process/per_thread');
+
 const {
   markTransferMode,
 } = require('internal/worker/js_transferable');
@@ -85,9 +90,6 @@ const {
 
 const querystring = require('querystring');
 
-const { platform } = process;
-const isWindows = platform === 'win32';
-
 const bindingUrl = internalBinding('url');
 
 const FORWARD_SLASH = /\//g;
@@ -349,7 +351,7 @@ class URLSearchParams {
           throw new ERR_ARG_NOT_ITERABLE('Query pairs');
         }
 
-        // The following implementationd differs from the URL specification:
+        // The following implementation differs from the URL specification:
         // Sequences must first be converted from ECMAScript objects before
         // and operations are done on them, and the operation of converting
         // the sequences would first exhaust the iterators. If the iterator
@@ -367,7 +369,7 @@ class URLSearchParams {
             if (pair.length !== 2) {
               throw new ERR_INVALID_TUPLE('Each query pair', '[name, value]');
             }
-            // Append (innerSequence[0], innerSequence[1]) to querys list.
+            // Append (innerSequence[0], innerSequence[1]) to query's list.
             ArrayPrototypePush(
               this.#searchParams,
               StringPrototypeToWellFormed(`${pair[0]}`),
@@ -1167,6 +1169,12 @@ ObjectDefineProperties(URL, {
     writable: true,
     enumerable: true,
   },
+  parse: {
+    __proto__: null,
+    configurable: true,
+    writable: true,
+    enumerable: true,
+  },
 });
 
 function installObjectURLMethods() {
@@ -1601,6 +1609,7 @@ module.exports = {
   installObjectURLMethods,
   URL,
   URLSearchParams,
+  URLParse: URL.parse,
   domainToASCII,
   domainToUnicode,
   urlToHttpOptions,
