@@ -10,10 +10,10 @@ const {
   SafePromiseAll,
   SafePromisePrototypeFinally,
   SafeSet,
+  TypeError,
   TypedArrayPrototypeGetBuffer,
   TypedArrayPrototypeGetByteLength,
   TypedArrayPrototypeGetByteOffset,
-  TypeError,
   Uint8Array,
 } = primordials;
 
@@ -31,6 +31,7 @@ const {
 
 const {
   CountQueuingStrategy,
+  ByteLengthQueuingStrategy,
 } = require('internal/webstreams/queuingstrategies');
 
 const {
@@ -52,6 +53,7 @@ const {
 } = require('buffer');
 
 const {
+  AbortError,
   ErrnoException,
   codes: {
     ERR_INVALID_ARG_TYPE,
@@ -59,7 +61,6 @@ const {
     ERR_INVALID_STATE,
     ERR_STREAM_PREMATURE_CLOSE,
   },
-  AbortError,
 } = require('internal/errors');
 
 const {
@@ -452,11 +453,7 @@ function newReadableStreamFromStreamReadable(streamReadable, options = kEmptyObj
       return new CountQueuingStrategy({ highWaterMark });
     }
 
-    // When not running in objectMode explicitly, we just fall
-    // back to a minimal strategy that just specifies the highWaterMark
-    // and no size algorithm. Using a ByteLengthQueuingStrategy here
-    // is unnecessary.
-    return { highWaterMark };
+    return new ByteLengthQueuingStrategy({ highWaterMark });
   };
 
   const strategy = evaluateStrategyOrFallback(options?.strategy);
